@@ -34,3 +34,20 @@ class DysInternalServerError(DysHttpException):
         self.status_code = 500
         self.message = message
         super().__init__(status_code=self.status_code, message=message)
+
+
+class DysBadGatewayError(DysHttpException):
+    """Raised when Dys Bad Gateway Error occurs with error code 502"""
+    def __init__(self, message="Dys Bad Gateway Error!"):
+        self.status_code = 502
+        self.message = message
+        super().__init__(status_code=self.status_code, message=message)
+
+
+class DysClearDirectoryItemDeleteException(DysHttpException):
+    """Raised when Dys Internal Server Error occurs with error code 500"""
+    def __init__(self, message="Clear Directory Item Delete Exception"):
+        self.status_code = 500
+        self.message = message
+        super().__init__(status_code=self.status_code, message=message)
+
